##  Fact Sheet Subtypes
Fact sheet subtypes are subcategories within fact sheet types that subclassify architectural elements, each focusing on distinct aspects. While subtypes share common properties with other subtypes, they also have unique attributes and relationships.
Not all fact sheet types have predefined subtypes. The table below gives a summary of available fact sheet subtypes:
Fact Sheet Type | Subtype Translation | Availability
---|---|---
Application | Business Application | Optional
Microservice | Optional
AI Agent | Optional
Business Context | Customer Journey |  Default
Process  | Default
Business Product  | Default
Value Stream | Default
ESG Capability | Optional
Initiative | Idea | Default
Program | Default
Project | Default
Epic | Default
Interface | API  | Default
Logical Interface | Default
IT Component | SaaS | Default
IaaS | Default
PaaS | Default
Software | Default
Hardware | Default
Services | Default
AI Model | Default (in new workspaces created after October 29, 2025)
Organization | Business Unit | Default
Customer | Default
Region | Default
Legal Entity | Default
Team | Default


YesNo
Send
